@@ -11,36 +11,15 @@ import auto_editor
 import auto_editor.vanparse as vanparse
 import auto_editor.utils.func as usefulfunctions
 
-from auto_editor.utils.func import fnone, append_filename
+from auto_editor.utils.progressbar import ProgressBar
+from auto_editor.utils.effects import Effect
+from auto_editor.utils.func import fnone, append_filename, set_output_name
 from auto_editor.utils.log import Log, Timer
 from auto_editor.ffwrapper import FFmpeg
 
-def set_output_name(path, making_data_file, args):
-    dot_index = path.rfind('.')
-
-    if(dot_index == -1):
-        root = path
-    else:
-        root = path[:dot_index]
-
-    if(args.export_as_json):
-        return root + '.json'
-    if(args.export_to_final_cut_pro):
-        return root + '.fcpxml'
-    if(args.export_to_shotcut):
-        return root + '.mlt'
-    if(making_data_file):
-        return root + '.xml'
-    if(args.export_as_audio):
-        return root + '_ALTERED.wav'
-
-    ext = path[dot_index:]
-    return root + '_ALTERED' + ext
-
-
 def main_options(parser):
     from auto_editor.utils.types import (file_type, float_type, sample_rate_type,
-        frame_type, zoom_type, rect_type, range_type, speed_range_type, block_type)
+        frame_type, range_type, speed_range_type, block_type)
 
     parser.add_argument('progressOps', nargs=0, action='grouping')
     parser.add_argument('--machine_readable_progress', action='store_true',
@@ -82,10 +61,10 @@ def main_options(parser):
         help='manually set the YouTube ID the video belongs to.')
     parser.add_argument('--block', type=block_type, group='urlOps',
         help='mark all sponsors sections as silent.',
-        extra='Only for YouTube urls. This uses the SponsorBlock api.\n'\
+        extra='Only for YouTube urls. This uses the SponsorBlock api.\n'
             'Choices can include: sponsor intro outro selfpromo interaction music_offtopic')
     parser.add_argument('--download_archive', type=file_type, default=None, group='urlOps',
-        help='Download only videos not listed in the archive file. Record the IDs of' \
+        help='Download only videos not listed in the archive file. Record the IDs of'
              ' all downloaded videos in it')
     parser.add_argument('--cookies', type=file_type, default=None, group='urlOps',
         help='The file to read cookies from and dump the cookie jar in.')
@@ -120,33 +99,43 @@ def main_options(parser):
         choices=['unset', 'yes', 'no'],
         help='skip variable frame rate scan, saving time for big video files.')
 
-    parser.add_argument('--render', default='auto', choices=['av', 'opencv', 'auto'],
-        help='choice which method to render video.')
+    parser.add_argument('effectOps', nargs=0, action='grouping')
+    parser.add_argument('--zoom', nargs='*', type=dict, group='effectOps',
+        help='set when and how a zoom will occur.',
+        keywords=[
+            {'start': ''}, {'end': ''}, {'zoom': ''}, {'end_zoom': '{zoom}'},
+            {'x': 'centerX'}, {'y': 'centerY'}, {'interpolate': 'linear'},
+        ])
+    parser.add_argument('--rectangle', nargs='*', type=dict, group='effectOps',
+        keywords=[
+            {'start': ''}, {'end': ''}, {'x1': ''}, {'y1': ''},
+            {'x2': ''}, {'y2': ''}, {'fill': '#000'}, {'width': 0}, {'outline': 'blue'}
+        ],
+        help='overlay a rectangle shape on the video.')
+    parser.add_argument('--circle', nargs='*', type=dict, group='effectOps',
+        keywords=[
+            {'start': ''}, {'end': ''}, {'x1': ''}, {'y1': ''},
+            {'x2': ''}, {'y2': ''}, {'fill': '#000'}, {'width': 0}, {'outline': 'blue'}
+        ],
+        help='overlay a circle shape on the video.',
+        extra='\n\nThe x and y coordinates specify a bounding box where the circle is '\
+            'drawn.')
+
+    parser.add_argument('--background', type=str, default='#000',
+        help='set the color of the background that is visible when the video is moved.')
+    parser.add_argument('--render', default='auto', hidden=True,
+        help="defunct option. doesn't do anything.")
     parser.add_argument('--scale', type=float_type, default=1,
         help='scale the output media file by a certain factor.')
     parser.add_argument('--combine_files', action='store_true',
         help='combine all input files into one before editing.')
 
-    parser.add_argument('--zoom', type=zoom_type, nargs='*',
-        help='set when and how a zoom will occur.',
-        extra='The arguments are: start,end,start_zoom,end_zoom,x,y,inter,hold' \
-            '\nThere must be at least 3 comma args. x and y default to centerX and centerY' \
-            '\nThe default interpolation is linear.')
-    parser.add_argument('--rectangle', type=rect_type, nargs='*',
-        help='overlay a rectangle shape on the video.',
-        extra='The arguments are: start,end,x1,y1,x2,y2,color,thickness' \
-            '\nThere must be at least 6 comma args. The rectangle is solid if' \
-            ' thickness is not defined.\n The default color is #000.')
-
-    parser.add_argument('--background', type=str, default='#000',
-        help='set the color of the background that is visible when the video is moved.')
-
     parser.add_argument('--mark_as_loud', type=range_type, nargs='*',
         help='the range that will be marked as "loud".')
     parser.add_argument('--mark_as_silent', type=range_type, nargs='*',
         help='the range that will be marked as "silent".')
     parser.add_argument('--cut_out', type=range_type, nargs='*',
-        help='the range of media that will be removed completely, regardless of the '\
+        help='the range of media that will be removed completely, regardless of the '
             'value of silent speed.')
     parser.add_argument('--add_in', type=range_type, nargs='*',
         help='the range of media that will be added in, opposite of --cut_out')
@@ -235,7 +224,7 @@ def main_options(parser):
         help='set the speed that "loud" sections should be played at.')
     parser.add_argument('--frame_margin', '--margin', '-m', type=frame_type, default=6,
         range='0 to Infinity',
-        help='set how many "silent" frames of on either side of "loud" sections '\
+        help='set how many "silent" frames of on either side of "loud" sections '
             'be included.')
 
     parser.add_argument('--help', '-h', action='store_true',
@@ -299,18 +288,8 @@ def get_chunks(inp, speeds, segment, fps, args, log, audio_samples=None, sample_
         fps, args, log)
 
 
-def get_effects(audio_samples, sample_rate, fps, args, log):
-    effects = []
-    if(args.zoom != []):
-        from auto_editor.cutting import applyZooms
-        effects += applyZooms(args.zoom, audio_samples, sample_rate, fps, log)
-    if(args.rectangle != []):
-        from auto_editor.cutting import applyRects
-        effects += applyRects(args.rectangle, audio_samples, sample_rate, fps, log)
-    return effects
-
-def edit_media(i, inp, ffmpeg, args, speeds, segment, exporting_to_editor, data_file,
-    TEMP, log):
+def edit_media(i, inp, ffmpeg, args, progress, speeds, segment, exporting_to_editor,
+    data_file, TEMP, log):
     chunks = None
     if(inp.ext == '.json'):
         from auto_editor.formats.make_json import read_json_cutlist
@@ -414,9 +393,11 @@ def edit_media(i, inp, ffmpeg, args, speeds, segment, exporting_to_editor, data_
                 os.path.join(TEMP, '{}.wav'.format(t))])
         cmd.extend(['-map', '0:v:0'])
         if(args.has_vfr == 'unset'):
+            log.conwrite('Extracting audio / detecting VFR')
             cmd.extend(['-vf', 'vfrdet', '-f', 'null', '-'])
             has_vfr = has_VFR(cmd, log)
         else:
+            log.conwrite('Extracting audio')
             ffmpeg.run(cmd)
             has_vfr = args.has_vfr == 'yes'
         del cmd
@@ -441,11 +422,16 @@ def edit_media(i, inp, ffmpeg, args, speeds, segment, exporting_to_editor, data_
             from auto_editor.scipy.wavfile import read
             sample_rate, audio_samples = read(temp_file)
 
+    effects = Effect(args, log, _vars={
+        'silent_threshold': args.silent_threshold
+        })
+    effects.audio_samples = audio_samples
+    effects.sample_rate = sample_rate
+
     log.debug('Frame Rate: {}'.format(fps))
     if(chunks is None):
         chunks = get_chunks(inp, speeds, segment, fps, args, log, audio_samples,
             sample_rate)
-        effects = get_effects(audio_samples, sample_rate, fps, args, log)
 
     def is_clip(chunk):
         # type: (list) -> bool
@@ -485,8 +471,8 @@ def edit_media(i, inp, ffmpeg, args, speeds, segment, exporting_to_editor, data_
     if(args.export_to_final_cut_pro or args.export_to_resolve):
         from auto_editor.formats.final_cut_pro import fcp_xml
 
-        totalFrames = chunks[len(chunks) - 1][1]
-        fcp_xml(inp, TEMP, output_path, clips, tracks, totalFrames, audio_file, fps, log)
+        total_frames = chunks[len(chunks) - 1][1]
+        fcp_xml(inp, TEMP, output_path, clips, tracks, total_frames, audio_file, fps, log)
         return num_cuts, output_path
 
     if(args.export_to_shotcut):
@@ -501,8 +487,7 @@ def edit_media(i, inp, ffmpeg, args, speeds, segment, exporting_to_editor, data_
             TEMP, log)
 
         temp_file = os.path.join(TEMP, 'convert.wav')
-        make_new_audio(the_file, temp_file, chunks, speeds, log, fps,
-            args.machine_readable_progress, args.no_progress)
+        make_new_audio(the_file, temp_file, chunks, speeds, log, fps, progress)
         convert_audio(ffmpeg, temp_file, inp, output_path, args.audio_codec, log)
 
     if(audio_file):
@@ -525,36 +510,11 @@ def edit_media(i, inp, ffmpeg, args, speeds, segment, exporting_to_editor, data_
             cut_subtitles(ffmpeg, inp, chunks, speeds, fps, TEMP, log)
 
         continue_video = handle_audio_tracks(ffmpeg, output_path, args, tracks, chunks,
-            speeds, fps, TEMP, log)
+            speeds, fps, progress, TEMP, log)
         if(continue_video):
-            if(args.render == 'auto'):
-                if(args.zoom != [] or args.rectangle != []):
-                    args.render = 'opencv'
-                else:
-                    try:
-                        import av
-                        args.render = 'av'
-                    except ImportError:
-                        args.render = 'opencv'
-
-            log.debug('Using {} method'.format(args.render))
-            if(args.render == 'av'):
-                if(args.zoom != []):
-                    log.error('Zoom effect is not supported on the '\
-                        'av render method.')
-
-                if(args.rectangle != []):
-                    log.error('Rectangle effect is not supported on the '\
-                        'av render method.')
-
-                from auto_editor.render.av import render_av
-                spedup = render_av(ffmpeg, inp, args, chunks, speeds, fps, has_vfr,
-                    TEMP, log)
-
-            if(args.render == 'opencv'):
-                from auto_editor.render.opencv import render_opencv
-                spedup = render_opencv(ffmpeg, inp, args, chunks, speeds, fps, has_vfr,
-                    effects, TEMP, log)
+            from auto_editor.render.av import render_av
+            spedup = render_av(ffmpeg, inp, args, chunks, speeds, fps, has_vfr,
+                progress, effects, TEMP, log)
 
             if(log.is_debug):
                 log.debug('Writing the output file.')
@@ -582,13 +542,13 @@ def edit_media(i, inp, ffmpeg, args, speeds, segment, exporting_to_editor, data_
             return [start] + [item] + [end]
 
         i = 1
-        totalFrames = chunks[len(chunks) - 1][1]
+        total_frames = chunks[len(chunks) - 1][1]
         speeds.append(99999) # guarantee we have a cut speed to work with.
         for chunk in chunks:
             if(speeds[chunk[2]] == 99999):
                 continue
 
-            make_video_file(inp, pad_chunk(chunk, totalFrames),
+            make_video_file(inp, pad_chunk(chunk, total_frames),
                 append_filename(output_path, '-{}'.format(i)))
             i += 1
     else:
@@ -598,12 +558,12 @@ def edit_media(i, inp, ffmpeg, args, speeds, segment, exporting_to_editor, data_
 
 def main():
     parser = vanparse.ArgumentParser('Auto-Editor', auto_editor.version,
-        description='\nAuto-Editor is an automatic video/audio creator and editor. '\
-            'By default, it will detect silence and create a new video with those '\
-            'sections cut out. By changing some of the options, you can export to a '\
-            'traditional editor like Premiere Pro and adjust the edits there, adjust '\
-            'the pacing of the cuts, and change the method of editing like using audio '\
-            'loudness and video motion to judge making cuts.\nRun:\n    auto-editor '\
+        description='\nAuto-Editor is an automatic video/audio creator and editor. '
+            'By default, it will detect silence and create a new video with those '
+            'sections cut out. By changing some of the options, you can export to a '
+            'traditional editor like Premiere Pro and adjust the edits there, adjust '
+            'the pacing of the cuts, and change the method of editing like using audio '
+            'loudness and video motion to judge making cuts.\nRun:\n    auto-editor '
             '--help\n\nTo get the list of options.\n')
 
     subcommands = ['create', 'test', 'info', 'levels', 'grep', 'subdump', 'desc']
@@ -664,7 +624,7 @@ def main():
     log.debug('Temp Directory: {}'.format(TEMP))
 
     if(args.input == []):
-        log.error('You need to give auto-editor an input file or folder so it can ' \
+        log.error('You need to give auto-editor an input file or folder so it can '
             'do the work for you.')
 
     if([args.export_to_premiere, args.export_to_resolve,
@@ -692,29 +652,25 @@ def main():
     if(args.dilates < 0):
         log.error('motionOps --dilates cannot be less than 0')
 
+    def write_starting_message(args):
+        if(args.export_to_premiere):
+            return 'Exporting to Adobe Premiere Pro XML file.'
+        if(args.export_to_final_cut_pro):
+            return 'Exporting to Final Cut Pro XML file.'
+        if(args.export_to_resolve):
+            return 'Exporting to DaVinci Resolve XML file.'
+        if(args.export_to_shotcut):
+            return 'Exporting to Shotcut XML Timeline file.'
+        if(args.export_as_audio):
+            return 'Exporting as audio.'
+        return 'Starting.'
 
-    def write_starting_message(args, log):
-        if(args.preview):
-            pass
-        elif(args.export_to_premiere):
-            log.conwrite('Exporting to Adobe Premiere Pro XML file.')
-        elif(args.export_to_final_cut_pro):
-            log.conwrite('Exporting to Final Cut Pro XML file.')
-        elif(args.export_to_resolve):
-            log.conwrite('Exporting to DaVinci Resolve XML file.')
-        elif(args.export_to_shotcut):
-            log.conwrite('Exporting to Shotcut XML Timeline file.')
-        elif(args.export_as_audio):
-            log.conwrite('Exporting as audio.')
-        else:
-            log.conwrite('Starting.')
-
-    write_starting_message(args, log)
+    if(not args.preview):
+        log.conwrite(write_starting_message(args))
 
     if(args.preview or args.export_as_clip_sequence or making_data_file):
         args.no_open = True
 
-    args.background = usefulfunctions.hex_to_bgr(args.background, log)
     if(args.blur < 0):
         args.blur = 0
 
@@ -762,14 +718,16 @@ def main():
     def main_loop(input_list, ffmpeg, args, speeds, segments, log):
         num_cuts = 0
 
+        progress = ProgressBar(args.machine_readable_progress, args.no_progress)
+
         for i, input_path in enumerate(input_list):
             inp = ffmpeg.file_info(input_path)
 
             if(len(input_list) > 1):
                 log.conwrite('Working on {}'.format(inp.basename))
 
-            cuts, output_path = edit_media(i, inp, ffmpeg, args, speeds, segments[i],
-                exporting_to_editor, making_data_file, TEMP, log)
+            cuts, output_path = edit_media(i, inp, ffmpeg, args, progress, speeds,
+                segments[i], exporting_to_editor, making_data_file, TEMP, log)
             num_cuts += cuts
 
         if(not args.preview and not making_data_file):
@@ -780,7 +738,7 @@ def main():
             time_save = usefulfunctions.human_readable_time(num_cuts * 30)
             s = 's' if num_cuts != 1 else ''
 
-            log.print('Auto-Editor made {} cut{}, which would have taken about {} if '\
+            log.print('Auto-Editor made {} cut{}, which would have taken about {} if '
                 'edited manually.'.format(num_cuts, s, time_save))
 
         if(not args.no_open):
