@@ -8,13 +8,60 @@ import os.path
 import subprocess
 
 # Included Libraries
-from auto_editor.utils.progressbar import ProgressBar
-from .utils import properties, scale_to_sped, pix_fmt_allowed
+from auto_editor.utils.func import fnone
 
-def render_av(ffmpeg, inp, args, chunks, speeds, fps, has_vfr, temp, log):
-    totalFrames = chunks[len(chunks) - 1][1]
-    videoProgress = ProgressBar(totalFrames, 'Creating new video',
-        args.machine_readable_progress, args.no_progress)
+def pix_fmt_allowed(pix_fmt):
+    # type: (str) -> bool
+
+    # From: github.com/PyAV-Org/PyAV/blob/main/av/video/frame.pyx
+    allowed_formats = ['yuv420p', 'yuvj420p', 'rgb24', 'bgr24', 'argb', 'rgba',
+        'abgr', 'bgra', 'gray', 'gray8', 'rgb8', 'bgr8', 'pal8']
+
+    return pix_fmt in allowed_formats
+
+def fset(cmd, option, value):
+    if(fnone(value)):
+        return cmd
+    return cmd + [option] + [value]
+
+def properties(cmd, args, inp):
+    if(args.video_codec == 'uncompressed'):
+        cmd.extend(['-vcodec', 'mpeg4', '-qscale:v', '1'])
+    elif(inp.ext == '.gif'):
+        cmd.extend(['-vcodec', 'gif'])
+    elif(args.video_codec == 'copy'):
+        new_codec = inp.video_streams[0]['codec']
+        if(new_codec != 'dvvideo'): # This codec seems strange.
+            cmd.extend(['-vcodec', new_codec])
+    else:
+        cmd = fset(cmd, '-vcodec', args.video_codec)
+
+    cmd = fset(cmd, '-crf', args.constant_rate_factor)
+    cmd = fset(cmd, '-b:v', args.video_bitrate)
+    cmd = fset(cmd, '-tune', args.tune)
+    cmd = fset(cmd, '-preset', args.preset)
+
+    cmd.extend(['-movflags', '+faststart', '-strict', '-2'])
+    return cmd
+
+def scale_to_sped(ffmpeg, spedup, scale, inp, args, temp):
+    cmd = ['-i', scale]
+    cmd = properties(cmd, args, inp)
+    cmd.append(spedup)
+    check_errors = ffmpeg.pipe(cmd)
+
+    if('Error' in check_errors or 'failed' in check_errors):
+        cmd = ['-i', scale]
+        if('-allow_sw 1' in check_errors):
+            cmd.extend(['-allow_sw', '1'])
+
+        cmd = properties(cmd, args, inp)
+        cmd.append(sped)
+        ffmpeg.run(cmd)
+
+def render_av(ffmpeg, inp, args, chunks, speeds, fps, has_vfr, progress, effects, temp, log):
+    total_frames = chunks[len(chunks) - 1][1]
+    progress.start(total_frames, 'Creating new video')
 
     input_ = av.open(inp.path)
     pix_fmt = input_.streams.video[0].pix_fmt
@@ -55,13 +102,23 @@ Convert your video to a supported pix_fmt. The following command might work for
     elif(not pix_fmt_allowed(pix_fmt)):
         throw_pix_fmt(inp, pix_fmt, log)
 
+    log.debug('pix_fmt: {}'.format(pix_fmt))
+
     inputVideoStream = input_.streams.video[0]
     inputVideoStream.thread_type = 'AUTO'
 
     width = inputVideoStream.width
     height = inputVideoStream.height
 
-    log.debug('pix_fmt: {}'.format(pix_fmt))
+    effects.add_var('fps', fps)
+    effects.add_var('width', width)
+    effects.add_var('height', height)
+    effects.add_var('start', 0)
+    effects.add_var('end', total_frames - 1)
+    effects.add_var('centerX', width // 2)
+    effects.add_var('centerY', height // 2)
+
+    effects.resolve(args)
 
     cmd = ['-hide_banner', '-y', '-f', 'rawvideo', '-vcodec', 'rawvideo',
         '-pix_fmt', pix_fmt, '-s', '{}*{}'.format(width, height), '-framerate', str(fps),
@@ -97,11 +154,16 @@ Convert your video to a supported pix_fmt. The following command might work for
                     inputEquavalent += (1 / speeds[chunk[2]])
 
                 while inputEquavalent > outputEquavalent:
+
+                    if(index-1 in effects.sheet):
+                        frame = effects.apply(index-1, frame, pix_fmt)
+
                     in_bytes = frame.to_ndarray().tobytes()
                     process2.stdin.write(in_bytes)
                     outputEquavalent += 1
 
-                videoProgress.tick(index - 1)
+                progress.tick(index - 1)
+        progress.end()
         process2.stdin.close()
         process2.wait()
     except BrokenPipeError:
